general_params

%Load station IDs
tmpdat = importdata([GPSDataDir '/stationlist.txt']);
assignin('base','names',tmpdat.rowheaders);
assignin('base','stationlocs',tmpdat.data);
clear tmpdat
ntot = length(names);

%subsample to region of interest
[lon_sta,lat_sta,ele_sta,x,y,names,n] = select_sites(stationlocs,names);

%calculate inter-station distances, used in culling out stations with too few neighbors
dists=1e10*diag(ones(1,n));
for i=1:n
    dists(i,:)=sqrt((x(i)-x).^2+(y(i)-y).^2);
end
oplot   = [-1 1;-1 1]; %used in plotting

%load earthquake dates and do forward model of ground deformation
load_init_EQ

%build empty status structure.  state: 1=<1 year of data, 2=too few points in testing period, 3=too few neighbors
status(1:length(names))  = struct('state',[0],'trigger',[0]','resN',NaN,'resE',NaN,'Nstd',NaN,'Estd',NaN);

for i=1:n
  
    %read data for site
    name                            = [GPSDataDir '/' names{i} '.' AC '.' product '.pos'];
    [daten,Ndel,Edel,Udel,nn,ee,uu] = read_data_pbo(name);
    nnm                             = median(nn);
    eem                             = median(ee);
    uum                             = median(uu);

    %count neighbors within maxdists
    distid    = find(dists(i,:)<=distneighb);
   
    %pick out dates for test
    testdates = find(daten>=RunDate-testcutoff);
    
    if(max(daten)-min(daten)<365)
        mydisp(['Less than one year of data for station ' names{i}],cflag)
        status(i).state   = 1;
    elseif(length(testdates)<=testnum)
        mydisp(['Too few points in detection testing period for station ' names{i}],cflag)
        status(i).state   = 2;
     elseif(length(distid)<numneighb)
        mydisp(['Too few neighbors for station ' names{i}],cflag)
        status(i).state   = 3;
    else
        
        %pick out EQs that affect this station
        id=find(and(and(EQdaten>=EQstart,EQdaten<=max(daten)),(EQux(:,i)>eem/5+EQuy(:,i)>nnm/5+EQuz(:,i)>uum/5)));
        
        %fit for secular rate, EQ offsets and postseismic
        [resE,resN,fitinfo] = fit_individ(daten,Edel,Ndel,EQdaten(id));
        Nstd                = std(resN(testdates));
        Estd                = std(resE(testdates));
 
        if(or(sum(abs(resN(testdates))>Nstd*nsig)>=testnum,sum(abs(resE(testdates))>Estd*nsig)>=testnum))
            status(i).trigger=1;
        end
        
        if(or(pflag==3,and(pflag==2,status(i).trigger)))
            plot_step
            pause
            close
        end
        status(i).fitinfo = fitinfo;
        status(i).Nstd    = Nstd;
        status(i).Estd    = Estd;
        status(i).resN    = resN(end);
        status(i).resE    = resE(end);
        
    end
end


%find sites that triggered on east, north
idtrig = find([status.trigger]);

finaltrig = [];
solotrig  = [];
%find all sites where enough neighbors also triggered
for i=1:length(idtrig)
    %count neighbors within maxdists
    distid=find(dists(idtrig(i),:)<=distneighb);
    
    if(sum(ismember(distid,idtrig))>=numneighb)
        mydisp(['neighbor triggered for site ' names{idtrig(i)}],cflag)
        finaltrig=[finaltrig idtrig(i)];
    else
        solotrig=[solotrig idtrig(i)];
    end
    
end

if(finaltrig)
    make_csv(lon_sta(finaltrig),lat_sta(finaltrig),testnum)
    make_plots(lon_sta,lat_sta,names,status,solotrig,finaltrig)
end

